@@ -1,6 +1,5 @@
 from .cch_dialog import CchDialog
 from ta_cch_axcess import logger
-from pywinauto.timings import TimeoutError as pywinautoTimeoutError
 
 
 class Documents(CchDialog):
@@ -20,17 +19,8 @@ class Documents(CchDialog):
         )
         logger.info("Complete!")
 
-    def get_files_by_client_id(self, client_id, folder_name):
+    def get_files_by_client_id(self, client_id):
         logger.info(f"Getting files of client id: {client_id}")
-        self.window.child_window(auto_id="txtClientFilter", class_name="TextBox").click_input()
-        self.window.child_window(auto_id="txtClientFilter", class_name="TextBox").type_keys(client_id + "{ENTER}")
-        self.window.child_window(auto_id="txtClientFilter", class_name="TextBox").type_keys("{DOWN}{ENTER}")
-
-        try:
-            self.window.child_window(auto_id="cmbRecordsPerPage").wait("ready", timeout=15)
-            self.window.child_window(auto_id="cmbRecordsPerPage").select("2000")
-        except pywinautoTimeoutError as e:
-            logger.warning(f"{e} - No option to change display in file list presented")
 
         self.window.child_window(title="Incoming files", class_name="TabItem").click_input()
 
@@ -67,7 +57,7 @@ class Documents(CchDialog):
                         for datagrid in datagrids:
                             if "Records" in datagrid.legacy_properties()["Name"]:
                                 list_data = datagrid.children(class_name="Record")
-                                cell_to_click = list_data[int(files_number) - 1].children(class_name="Cell")
+                                self.cell_to_click = list_data[int(files_number) - 1].children(class_name="Cell")
 
         self.window.child_window(
             title="CCH.Document.UI.DocumentCentral.UIClasses.PendingApprovalEntityInfo",
@@ -87,7 +77,8 @@ class Documents(CchDialog):
         self.window.type_keys(keys_to_press)
         self.window.type_keys("{VK_SHIFT up}{VK_CONTROL up}")
 
-        cell_to_click[0].right_click_input()
+    def download_files(self, folder_name):
+        self.cell_to_click[0].right_click_input()
 
         self.window.child_window(auto_id="mnuDownloadExistingCopy").wait("exists", timeout=15)
         self.window.child_window(auto_id="mnuDownloadExistingCopy").click_input()
